@@ -1,16 +1,22 @@
 package aQute.bnd.osgi;
 
-import java.nio.charset.*;
-import java.util.*;
-import java.util.regex.*;
+import java.nio.charset.Charset;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Set;
+import java.util.regex.Pattern;
 
 public interface Constants {
 	/*
 	 * Defined in OSGi
 	 */
 	/**
-	 * @syntax Bundle-ActivationPolicy ::= policy ( ’;’ directive )* policy ::=
-	 *         ’lazy’
+	 * <pre>
+	 * Bundle-ActivationPolicy ::= policy ( ’;’ directive )*
+	 * policy ::= ’lazy’
+	 * </pre>
 	 */
 	String							BND_ADDXMLTOTEST							= "Bnd-AddXMLToTest";
 	String							BUNDLE_ACTIVATIONPOLICY						= "Bundle-ActivationPolicy";
@@ -35,17 +41,20 @@ public interface Constants {
 	String							BUNDLE_VERSION								= "Bundle-Version";
 	String							BUNDLE_DEVELOPERS							= "Bundle-Developers";
 	String							BUNDLE_CONTRIBUTORS							= "Bundle-Contributors";
+	String							BUNDLE_SCM									= "Bundle-SCM";
 	String							DYNAMICIMPORT_PACKAGE						= "DynamicImport-Package";
 	String							EXPORT_PACKAGE								= "Export-Package";
 	String							EXPORT_SERVICE								= "Export-Service";
 	String							FRAGMENT_HOST								= "Fragment-Host";
 	String							IMPORT_PACKAGE								= "Import-Package";
 	String							IMPORT_SERVICE								= "Import-Service";
+	String							LAUNCHER_PLUGIN								= "Launcher-Plugin";
 	String							META_PERSISTENCE							= "Meta-Persistence";
 	String							PROVIDE_CAPABILITY							= "Provide-Capability";
 	String							REQUIRE_BUNDLE								= "Require-Bundle";
 	String							REQUIRE_CAPABILITY							= "Require-Capability";
 	String							SERVICE_COMPONENT							= "Service-Component";
+	String							TESTER_PLUGIN								= "Tester-Plugin";
 
 	String							PRIVATE_PACKAGE								= "Private-Package";
 	String							IGNORE_PACKAGE								= "Ignore-Package";
@@ -60,12 +69,13 @@ public interface Constants {
 	String							headers[]									= {
 			BUNDLE_ACTIVATOR, BUNDLE_CONTACTADDRESS, BUNDLE_COPYRIGHT, BUNDLE_DESCRIPTION, BUNDLE_DOCURL,
 			BUNDLE_LOCALIZATION, BUNDLE_NATIVECODE, BUNDLE_VENDOR, BUNDLE_VERSION, BUNDLE_LICENSE, BUNDLE_CLASSPATH,
-			SERVICE_COMPONENT, EXPORT_PACKAGE, IMPORT_PACKAGE, BUNDLE_LOCALIZATION, BUNDLE_MANIFESTVERSION,
-			BUNDLE_NAME, BUNDLE_NATIVECODE, BUNDLE_REQUIREDEXECUTIONENVIRONMENT, BUNDLE_SYMBOLICNAME, BUNDLE_VERSION,
-			FRAGMENT_HOST, PRIVATE_PACKAGE, IGNORE_PACKAGE, INCLUDE_RESOURCE, REQUIRE_BUNDLE, IMPORT_SERVICE,
-			EXPORT_SERVICE, CONDITIONAL_PACKAGE, BND_LASTMODIFIED, TESTCASES, REQUIRE_CAPABILITY, PROVIDE_CAPABILITY,
-			BUNDLE_ICON, REPOSITORIES, META_PERSISTENCE, BUNDLE_DEVELOPERS, BUNDLE_CONTRIBUTORS
-																				};
+			SERVICE_COMPONENT, EXPORT_PACKAGE, IMPORT_PACKAGE, BUNDLE_LOCALIZATION, BUNDLE_MANIFESTVERSION, BUNDLE_NAME,
+			BUNDLE_NATIVECODE, BUNDLE_REQUIREDEXECUTIONENVIRONMENT, BUNDLE_SYMBOLICNAME, BUNDLE_VERSION, FRAGMENT_HOST,
+			PRIVATE_PACKAGE, IGNORE_PACKAGE, INCLUDE_RESOURCE, REQUIRE_BUNDLE, IMPORT_SERVICE, EXPORT_SERVICE,
+			CONDITIONAL_PACKAGE, BND_LASTMODIFIED, TESTCASES, REQUIRE_CAPABILITY, PROVIDE_CAPABILITY, BUNDLE_ICON,
+			REPOSITORIES, META_PERSISTENCE, BUNDLE_DEVELOPERS, BUNDLE_CONTRIBUTORS, BUNDLE_SCM, LAUNCHER_PLUGIN,
+			TESTER_PLUGIN
+	};
 
 	String							BASELINE									= "-baseline";
 	String							BASELINEREPO								= "-baselinerepo";
@@ -85,17 +95,21 @@ public interface Constants {
 	@Deprecated
 	String							BUILDPACKAGES								= "-buildpackages";
 	String							BUMPPOLICY									= "-bumppolicy";
+	String							CHECK										= "-check";
 	String							CONDUIT										= "-conduit";
 	String							CONTRACT									= "-contract";
 	@Deprecated
 	String							CACHEDIR									= "-cachedir";
 	String							CONDITIONALPACKAGE							= "-conditionalpackage";
+	String							CONNECTION_SETTINGS							= "-connection-settings";
 	String							DIFFIGNORE									= "-diffignore";
 	String							DEPENDSON									= "-dependson";
 	String							DEPLOY										= "-deploy";
 	String							DEPLOYREPO									= "-deployrepo";
 	String							DIGESTS										= "-digests";
 	String							DSANNOTATIONS								= "-dsannotations";
+	String							DSANNOTATIONS_OPTIONS						= "-dsannotations-options";
+
 	String							DONOTCOPY									= "-donotcopy";
 	@Deprecated
 	String							DEBUG										= "-debug";
@@ -105,25 +119,34 @@ public interface Constants {
 	String							EXTENSION									= "-extension";
 	String							EEPROFILE									= "-eeprofile";
 	String							EXPORT										= "-export";
+	String							EXPORTTYPE									= "-exporttype";
 	String							FAIL_OK										= "-failok";
 	String							FIXUPMESSAGES								= "-fixupmessages";
-
 	String							GESTALT										= "-gestalt";
 	String							GESTALT_INTERACTIVE							= "interactive";
 	String							GESTALT_BATCH								= "batch";
 	String							GESTALT_CI									= "ci";
 	String							GESTALT_OFFLINE								= "offline";
 	String							GESTALT_SHELL								= "shell";
-
+	String							GROUPID										= "-groupid";
 	String							INCLUDE										= "-include";
 	String							INCLUDERESOURCE								= "-includeresource";
 	String							INVALIDFILENAMES							= "-invalidfilenames";
+	String							INIT										= "-init";
+	String							BUILDREPO									= "-buildrepo";
 	String							JAVAAGENT									= "-javaagent";
-
+	String							JAVAC_SOURCE								= "javac.source";
+	String							JAVAC_TARGET								= "javac.target";
+	String							JAVAC_PROFILE								= "javac.profile";
+	String							JAVAC										= "javac";
+	String							JAVA										= "java";
+	String							JAVA_DEBUG									= "java.debug";
 	String							MAKE										= "-make";
 	String							METATYPE									= "-metatype";
 	String							METATYPE_ANNOTATIONS						= "-metatypeannotations";
+	String							METATYPE_ANNOTATIONS_OPTIONS				= "-metatypeannotations-options";
 	String							MANIFEST									= "-manifest";
+	String							MAVEN_RELEASE								= "-maven-release";
 	String							PROFILE										= "-profile";
 	String							SAVEMANIFEST								= "-savemanifest";
 	String							NAMESECTION									= "-namesection";
@@ -138,11 +161,12 @@ public interface Constants {
 	String							MANIFEST_NAME								= "-manifest-name";
 	String							NOUSES										= "-nouses";
 	String							NOBUNDLES									= "-nobundles";
-	String							OUTPUTMASK									= "-outputmask";																																					// default
-																																																													// ${@bsn}.jar
+	String							OUTPUTMASK									= "-outputmask";																																						// default
+																																																														// ${@bsn}.jar
 	String							PACKAGE										= "-package";
 	String							PACKAGE_JPM									= "jpm";
 	String							PEDANTIC									= "-pedantic";
+	String							PACKAGEINFOTYPE								= "-packageinfotype";
 	String							PLUGIN										= "-plugin";
 	String							PLUGINPATH									= "-pluginpath";
 	String							PLUGINPATH_URL_ATTR							= "url";
@@ -151,6 +175,7 @@ public interface Constants {
 	String							PREPROCESSMATCHERS							= "-preprocessmatchers";
 	String							PRIVATEPACKAGE								= "-privatepackage";
 	String							RELEASEREPO									= "-releaserepo";
+	String							DISTRO										= "-distro";
 	String							REMOVEHEADERS								= "-removeheaders";
 	String							RESOURCEONLY								= "-resourceonly";
 	String							SIGNATURE_TEST								= "-signaturetest";
@@ -164,6 +189,10 @@ public interface Constants {
 	String							RUNSYSTEMCAPABILITIES						= "-runsystemcapabilities";
 	String							RUNBUNDLES									= "-runbundles";
 	String							RUNREPOS									= "-runrepos";
+	String							AUGMENT										= "-augment";
+	String							AUGMENT_RANGE_ATTRIBUTE						= "version:";
+	String							AUGMENT_CAPABILITY_DIRECTIVE				= "capability:";
+	String							AUGMENT_REQUIREMENT_DIRECTIVE				= "requirement:";
 
 	/**
 	 * @deprecated This is for support of the legacy OBR requirement format, use
@@ -175,6 +204,7 @@ public interface Constants {
 	String							RUNBLACKLIST								= "-runblacklist";
 	String							RUNREQUIRES									= "-runrequires";
 	String							RUNEE										= "-runee";
+	String							RUNKEEP										= "-runkeep";
 	String							RUNPATH										= "-runpath";
 	String							RUNSTORAGE									= "-runstorage";
 	String							RUNBUILDS									= "-runbuilds";
@@ -186,17 +216,20 @@ public interface Constants {
 	String							RUNTIMEOUT									= "-runtimeout";
 	String							RUNJDB										= "-runjdb";
 	String							RUNENV										= "-runenv";
+	String							RUNREMOTE									= "-runremote";
 	String							SYSTEMPROPERTIES							= "-systemproperties";
 	String							SNAPSHOT									= "-snapshot";
 	String							RUNFRAMEWORK_SERVICES						= "services";
 	String							RUNFRAMEWORK_NONE							= "none";
 	String							REPORTNEWER									= "-reportnewer";
 	String							SIGN										= "-sign";
+	String							STANDALONE									= "-standalone";
 	String							TESTPACKAGES								= "-testpackages";
 	String							TESTPATH									= "-testpath";
 	String							TESTCONTINUOUS								= "-testcontinuous";
 	String							TESTSOURCES									= "-testsources";
 	String							TESTUNRESOLVED								= "-testunresolved";
+	String							TESTER										= "-tester";
 	String							UNDERTEST									= "-undertest";
 	String							UPTO										= "-upto";
 	String							PROVIDER_POLICY								= "-provider-policy";
@@ -210,28 +243,34 @@ public interface Constants {
 	String							OUTPUT										= "-output";
 
 	String							options[]									= {
-			BASELINE, BUILDPATH, BUMPPOLICY, CONDUIT, CLASSPATH, CONSUMER_POLICY, DEPENDSON, DONOTCOPY,
-			EXPORT_CONTENTS, FAIL_OK, INCLUDE, INCLUDERESOURCE, MAKE, MANIFEST, NOEXTRAHEADERS, NOUSES, NOBUNDLES,
-			PEDANTIC, PLUGIN, POM, PROVIDER_POLICY, REMOVEHEADERS, RESOURCEONLY, SOURCES, SOURCEPATH, SOURCES,
-			SOURCEPATH, SUB, RUNBUNDLES, RUNPATH, RUNSYSTEMPACKAGES, RUNSYSTEMCAPABILITIES, RUNPROPERTIES, REPORTNEWER,
-			UNDERTEST, TESTPATH, TESTPACKAGES, NOMANIFEST, DEPLOYREPO, RELEASEREPO, SAVEMANIFEST, RUNVM,
-			RUNPROGRAMARGS, WAB, WABLIB, RUNFRAMEWORK, RUNFW, RUNTRACE, RUNBLACKLIST, TESTCONTINUOUS, SNAPSHOT,
-			NAMESECTION, DIGESTS, DSANNOTATIONS, BASELINE, BASELINEREPO, PROFILE, PACKAGE, RUNNOREFERENCES, JAVAAGENT,
+			BASELINE, BUILDPATH, BUMPPOLICY, CONDUIT, CLASSPATH, CONSUMER_POLICY, DEPENDSON, DONOTCOPY, EXPORT_CONTENTS,
+			FAIL_OK, INCLUDE, INCLUDERESOURCE, MAKE, MANIFEST, NOEXTRAHEADERS, NOUSES, NOBUNDLES, PEDANTIC, PLUGIN, POM,
+			PROVIDER_POLICY, REMOVEHEADERS, RESOURCEONLY, SOURCES, SOURCEPATH, SOURCES, SOURCEPATH, SUB, RUNBUNDLES,
+			RUNPATH, RUNSYSTEMPACKAGES, RUNSYSTEMCAPABILITIES, RUNPROPERTIES, REPORTNEWER, UNDERTEST, TESTPATH,
+			TESTPACKAGES, NOMANIFEST, DEPLOYREPO, RELEASEREPO, SAVEMANIFEST, RUNVM, RUNPROGRAMARGS, WAB, WABLIB,
+			RUNFRAMEWORK, RUNFW, RUNKEEP, RUNTRACE, RUNBLACKLIST, TESTCONTINUOUS, SNAPSHOT, NAMESECTION, DIGESTS,
+			DSANNOTATIONS, DSANNOTATIONS_OPTIONS, BASELINE, BASELINEREPO, PROFILE, PACKAGE, RUNNOREFERENCES, JAVAAGENT,
 			STRICT, DIFFIGNORE, CONTRACT, NOBUILDINCACHE, EXTENSION, NOJUNIT, NOJUNITOSGI, PREPROCESSMATCHERS, UPTO,
 			INVALIDFILENAMES, FIXUPMESSAGES, PRIVATEPACKAGE, CONDITIONALPACKAGE, NOEE, OUTPUTMASK, TESTUNRESOLVED,
-			RUNJDB, RUNENV, RUNEE, EEPROFILE, RUNREQUIRES, EXPORT, GESTALT, BNDDRIVER
-																				};
+			RUNJDB, RUNENV, RUNEE, EEPROFILE, RUNREQUIRES, EXPORT, GESTALT, BNDDRIVER, CHECK, DISTRO,
+			METATYPE_ANNOTATIONS, METATYPE_ANNOTATIONS_OPTIONS, PACKAGEINFOTYPE, JAVAC_SOURCE, JAVAC_TARGET,
+			JAVAC_PROFILE, JAVAC, JAVA, JAVA_DEBUG, EXPORTTYPE, RUNREMOTE, TESTER, AUGMENT, REQUIRE_BND, GROUPID,
+			STANDALONE, INIT, MAVEN_RELEASE, BUILDREPO, CONNECTION_SETTINGS
+
+	};
 
 	// Ignore bundle specific headers. These bundles do not make
 	// a lot of sense to inherit
 	String[]						BUNDLE_SPECIFIC_HEADERS						= new String[] {
 			INCLUDE_RESOURCE, BUNDLE_ACTIVATOR, BUNDLE_CLASSPATH, BUNDLE_NAME, BUNDLE_NATIVECODE, BUNDLE_SYMBOLICNAME,
 			IMPORT_PACKAGE, EXPORT_PACKAGE, DYNAMICIMPORT_PACKAGE, FRAGMENT_HOST, REQUIRE_BUNDLE, PRIVATE_PACKAGE,
-			PRIVATEPACKAGE, EXPORT_CONTENTS, TESTCASES, NOMANIFEST, WAB, WABLIB, REQUIRE_CAPABILITY,
-			PROVIDE_CAPABILITY, DSANNOTATIONS, SERVICE_COMPONENT, SIGNATURE_TEST
-																				};
+			PRIVATEPACKAGE, EXPORT_CONTENTS, TESTCASES, NOMANIFEST, WAB, WABLIB, REQUIRE_CAPABILITY, PROVIDE_CAPABILITY,
+			DSANNOTATIONS, SERVICE_COMPONENT, SIGNATURE_TEST, METATYPE_ANNOTATIONS
+	};
 
 	char							DUPLICATE_MARKER							= '~';
+	String							INTERNAL_EXPORTED_DIRECTIVE					= "-internal-exported:";
+	String							INTERNAL_SOURCE_DIRECTIVE					= "-internal-source:";
 	String							SPECIFICATION_VERSION						= "specification-version";
 	String							SPLIT_PACKAGE_DIRECTIVE						= "-split-package:";
 	String							EFFECTIVE_DIRECTIVE							= "effective:";
@@ -254,6 +293,7 @@ public interface Constants {
 	String							VISIBILITY_DIRECTIVE						= "visibility:";
 	String							FRAGMENT_ATTACHMENT_DIRECTIVE				= "fragment-attachment:";
 	String							RESOLUTION_DIRECTIVE						= "resolution:";
+	String							CARDINALITY_DIRECTIVE						= "cardinality:";
 	String							PATH_DIRECTIVE								= "path:";
 	String							SIZE_ATTRIBUTE								= "size";
 	String							LINK_ATTRIBUTE								= "link";
@@ -292,10 +332,11 @@ public interface Constants {
 			FROM_DIRECTIVE, PRIVATE_DIRECTIVE, LITERAL_ATTRIBUTE, EFFECTIVE_DIRECTIVE, FILTER_DIRECTIVE,
 			FIXUPMESSAGES_RESTRICT_DIRECTIVE, FIXUPMESSAGES_REPLACE_DIRECTIVE, FIXUPMESSAGES_IS_DIRECTIVE,
 			BNDDRIVER_GRADLE, BNDDRIVER_GRADLE_NATIVE, BNDDRIVER_ANT, BNDDRIVER_ECLIPSE, BNDDRIVER_MAVEN,
-			BNDDRIVER_INTELLIJ, BNDDRIVER_SBT, BNDDRIVER_OSMORC
+			BNDDRIVER_INTELLIJ, BNDDRIVER_SBT, BNDDRIVER_OSMORC, AUGMENT_CAPABILITY_DIRECTIVE,
+			AUGMENT_REQUIREMENT_DIRECTIVE
 
-																				// TODO
-																				};
+			// TODO
+	};
 
 	String							USES_USES									= "<<USES>>";
 	String							CURRENT_USES								= "@uses";
@@ -303,10 +344,10 @@ public interface Constants {
 	String							IMPORT_PRIVATE								= "private";
 	String[]						importDirectives							= {
 			IMPORT_REFERENCE, IMPORT_PRIVATE
-																				};
+	};
 
 	static final Pattern			VALID_PROPERTY_TYPES						= Pattern
-																						.compile("(String|Long|Double|Float|Integer|Byte|Character|Boolean|Short)");
+			.compile("(String|Long|Double|Float|Integer|Byte|Character|Boolean|Short)");
 
 	String							DEFAULT_BND_EXTENSION						= ".bnd";
 	String							DEFAULT_JAR_EXTENSION						= ".jar";
@@ -314,7 +355,7 @@ public interface Constants {
 	String							DEFAULT_BNDRUN_EXTENSION					= ".bndrun";
 	String[]						METAPACKAGES								= {
 			"META-INF", "OSGI-INF", "OSGI-OPT"
-																				};
+	};
 
 	String							CURRENT_VERSION								= "@";
 	String							CURRENT_PACKAGE								= "@package";
@@ -324,8 +365,6 @@ public interface Constants {
 	String							EMPTY_HEADER								= "<<EMPTY>>";
 
 	String							EMBEDDED_REPO								= "/embedded-repo.jar";
-	String							LAUNCHER_PLUGIN								= "Launcher-Plugin";
-	String							TESTER_PLUGIN								= "Tester-Plugin";
 
 	String							DEFAULT_LAUNCHER_BSN						= "biz.aQute.launcher";
 	String							DEFAULT_TESTER_BSN							= "biz.aQute.junit";
@@ -373,30 +412,27 @@ public interface Constants {
 			COMPONENT_SERVICEFACTORY, COMPONENT_VERSION, COMPONENT_CONFIGURATION_POLICY, COMPONENT_MODIFIED,
 			COMPONENT_ACTIVATE, COMPONENT_DEACTIVATE, COMPONENT_NAME, COMPONENT_DESCRIPTORS, COMPONENT_DESIGNATE,
 			COMPONENT_DESIGNATEFACTORY, COMPONENT_GREEDY, COMPONENT_NAMESPACE
-																				};
+	};
 
 	Set<String>						SET_COMPONENT_DIRECTIVES					= new HashSet<String>(
-																						Arrays.asList(componentDirectives));
+			Arrays.asList(componentDirectives));
 
-	Set<String>						SET_COMPONENT_DIRECTIVES_1_1				= //
-																				new HashSet<String>(Arrays.asList(
-																						COMPONENT_VERSION,
-																						COMPONENT_CONFIGURATION_POLICY,
-																						COMPONENT_MODIFIED,
-																						COMPONENT_ACTIVATE,
-																						COMPONENT_DEACTIVATE));
+	Set<String>						SET_COMPONENT_DIRECTIVES_1_1				=																																										//
+			new HashSet<String>(Arrays.asList(COMPONENT_VERSION, COMPONENT_CONFIGURATION_POLICY, COMPONENT_MODIFIED,
+					COMPONENT_ACTIVATE, COMPONENT_DEACTIVATE));
 
 	Set<String>						SET_COMPONENT_DIRECTIVES_1_2				= new HashSet<String>(
-																						Arrays.asList(COMPONENT_GREEDY));
+			Arrays.asList(COMPONENT_GREEDY));
 
 	String							VERSION_ATTR_LATEST							= "latest";
 	String							VERSION_ATTR_SNAPSHOT						= "snapshot";
 	String							VERSION_ATTR_PROJECT						= "project";
+	String							VERSION_ATTR_HASH							= "hash";
 
 	/**
 	 * List of standard matchers for preprocessing
 	 */
-	String							DEFAULT_PREPROCESSS_MATCHERS				= "!*.(jpg|jpeg|jif|jfif|jp2|jpx|j2k|j2c|fpx|png|gif|swf|doc|pdf|tiff|tif|raw|bmp|ppm|pgm|pbm|pnm|pfm|webp|zip|jar|gz|tar|tgz|exe|com|bin|mp[0-9]|mpeg|mov|):i, *";
+	String							DEFAULT_PREPROCESSS_MATCHERS				= "!*.(ico|jpg|jpeg|jif|jfif|jp2|jpx|j2k|j2c|fpx|png|gif|swf|doc|pdf|tiff|tif|raw|bmp|ppm|pgm|pbm|pnm|pfm|webp|zip|jar|gz|tar|tgz|exe|com|bin|mp[0-9]|mpeg|mov|):i, *";
 
 	/*
 	 * Default properties as listed in defaults.bnd
@@ -408,6 +444,12 @@ public interface Constants {
 	String							DEFAULT_PROP_TESTBIN_DIR					= "testbin";
 	String							DEFAULT_PROP_TARGET_DIR						= "target-dir";
 
+	/**
+	 * If set to a long (from epoch time), overrides the real time in the macro
+	 * processor for tstamp
+	 */
+	String							TSTAMP										= "_@tstamp";
+
 	/*
 	 * Deprecated Section
 	 */
